@@ -3,7 +3,7 @@
 use strict;
 package Data::Tabular;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use Carp qw (croak);
 
@@ -115,18 +115,6 @@ sub xls
     );
 }
 
-sub _xml
-{
-    my $self = shift;
-    require Data::Tabular::Output::XML;
-
-    return Data::Tabular::Output::XML->new(
-	table => $self->grouped,
-	output => $self->output,
-	@_,
-    );
-}
-
 sub txt 
 {
     my $self = shift;
